@@ -3,13 +3,16 @@ package Text::Markup::HTML;
 use 5.8.1;
 use strict;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
-    open my $fh, '<:raw', $file or die "Cannot open $file: $!\n";
-    local $/;
-    return <$fh>;
+    my $html = do {
+        open my $fh, '<:raw', $file or die "Cannot open $file: $!\n";
+        local $/;
+        <$fh>;
+    };
+    return $html =~ /\S/ ? $html : undef
 }
 
 1;
